/* This is a GENERATED file */
/*< private_header >*/
static const gchar developers[] =
    "David Nečas (Yeti)\n"
    "Petr Klapetek\n"
    "Christopher Anderson\n"
    "Martin Šiler\n"
    "Jindřich Bílek\n"
    "Nenad Ocelic\n"
    "Rok Zitko\n"
    "Lukáš Chvátal\n"
    "Sven Neumann\n"
    "Jan Hořák\n"
    "Александр Ковалев\n"
    "Owain Davies\n"
    "Rolf Würdemann\n"
    "Dirk Kähler\n"
    "Miroslav Valtr\n"
    "Martin Hasoň\n"
    "Philipp Rahe\n"
    "Matthew Caldwell\n"
    "Андрей Груздев\n"
    "Даниил Браташов\n"
    "François Bianco\n"
    "Luke Somers\n"
    "Vojtěch Salajka\n"
    "Anna Campbellova\n"
    "Lennart Fricke\n"
    "Jozef Veselý\n"
    "Gianfranco Gallizia\n"
    "Sameer Grover\n"
    "Niv Levy\n"
;
static const gchar translators[] =
    "David Nečas (Yeti)\n"
    "Petr Klapetek\n"
    "Livia Della Seta\n"
    "Philipp Leufke\n"
    "Johannes Römer\n"
    "François Riguet\n"
    "Даниил Браташов\n"
    "Andrés Muñiz Piniella\n"
;
static const gchar releasedate[] =
    "2013-09-08"
;
